Mpris

Struct Mpris 

pub struct Mpris {
    pub daemon: MusicPlayerClient,
    pub port: u16,
    pub state: RwLock<StateAudio>,
}

Fields

daemon: MusicPlayerClientport: u16state: RwLock<StateAudio>

Implementations

Source

impl Mpris

pub fn new_with_daemon(daemon: MusicPlayerClient) -> Self

Create a new Mpris instance with a daemon already connected.

pub async fn update_state(&self) -> Result<()>

Update the state from the daemon.

Errors

Returns an error if the state cannot be retrieved from the daemon.

pub async fn start_server( self, bus_name_suffix: &str, ) -> Result<Server<Self>, ZbusError>

Start the Mpris server.

Consumes self, but you can get back a reference to it by calling imp() on the returned Server.

Errors

Returns an error if the server cannot be started.