Struct Mpris

pub struct Mpris {
    pub port: u16,
    pub state: RwLock<StateAudio>,
    /* private fields */
}

Fields

port: u16state: RwLock<StateAudio>

Implementations

Source

impl Mpris

pub fn new(port: u16) -> Self

Create a new Mpris instance pending a connection to a daemon.

pub async fn daemon(&self) -> RwLockReadGuard<'_, Option<MusicPlayerClient>>

Give access to the inner Daemon client (checks if the daemon is connected first).

pub fn new_with_daemon(daemon: MusicPlayerClient) -> Self

Create a new Mpris instance with a daemon already connected.

pub async fn connect(&self) -> Result<()>

Connect to the daemon.

Errors

Returns an error if the daemon cannot be connected.

pub async fn connect_with_retry(&self) -> Result<()>

Connect to the daemon if not already connected.

Errors

Returns an error if the daemon cannot be connected after 5 retries.

pub async fn start_server( self, bus_name_suffix: &str, ) -> Result<Server<Self>, ZbusError>

Start the Mpris server.

Consumes self, but you can get back a reference to it by calling imp() on the returned Server.

Errors

Returns an error if the server cannot be started.